@@ -16,7 +16,7 @@ use crate::{
 
 pub fn register_commands(commands: &mut CommandManager, plugin_handle: PluginHandle) {
     let mut r = |name, completions, command_fn| {
-        commands.register(Some(plugin_handle), name, completions, command_fn);
+        commands.register_command(Some(plugin_handle), name, completions, command_fn);
     };
 
     r("lsp", &[], |ctx, io| {
