@@ -7,7 +7,7 @@ fn main() {
 
     config
         .static_configs
-        .push(pepper_plugin_lsp::DEFAULT_BINDINGS_CONFIG);
+        .push(pepper_plugin_lsp::DEFAULT_CONFIGS);
 
     pepper::run(config);
 }
