@@ -25,7 +25,13 @@ pub enum Uri<'a> {
 }
 impl<'a> Uri<'a> {
     pub fn parse(root: &'a Path, uri: &'a str) -> Result<Self, UriParseError> {
-        let uri = uri.strip_prefix("file:///").ok_or(UriParseError)?;
+        let uri = uri.strip_prefix("file://").ok_or(UriParseError)?;
+        let uri_without_root = uri.strip_prefix("/").ok_or(UriParseError)?;
+        let uri = match Path::new(uri_without_root).components().next() {
+            Some(Component::Prefix(_)) => uri_without_root,
+            _ => uri,
+        };
+
         let path = Path::new(uri);
         let path = path.strip_prefix(root).unwrap_or(path);
         Ok(Self::Path(path))
@@ -590,6 +596,7 @@ impl<'json> FromJson<'json> for WorkspaceEditChange {
 
 #[derive(Default)]
 pub struct WorkspaceEdit {
+    changes: JsonObject,
     document_changes: JsonArray,
 }
 impl WorkspaceEdit {
@@ -600,6 +607,45 @@ impl WorkspaceEdit {
         root: &Path,
         json: &Json,
     ) {
+        for (uri, text_edits) in self.changes.clone().members(json) {
+            let path = match Uri::parse(&root, uri) {
+                Ok(Uri::Path(path)) => path,
+                Err(_) => return,
+            };
+            let buffer_handle = editor
+                .buffers
+                .find_with_path(&editor.current_directory, path);
+
+            let (is_temp, buffer_handle) = match buffer_handle {
+                Some(handle) => (false, handle),
+                None => {
+                    let buffer = editor.buffers.add_new();
+                    buffer.properties = BufferProperties::scratch();
+                    buffer.properties.saving_enabled = true;
+                    buffer.set_path(path);
+                    let _ = buffer.read_from_file(&mut editor.word_database, &mut editor.events);
+                    (true, buffer.handle())
+                }
+            };
+
+            let text_edits = match text_edits {
+                JsonValue::Array(array) => array,
+                _ => return,
+            };
+            TextEdit::apply_edits(editor, buffer_handle, temp_edits, text_edits, json);
+
+            if is_temp {
+                let _ = editor
+                    .buffers
+                    .get_mut(buffer_handle)
+                    .write_to_file(None, &mut editor.events);
+
+                editor
+                    .buffers
+                    .defer_remove(buffer_handle, &mut editor.events);
+            }
+        }
+
         for change in self.document_changes.clone().elements(json) {
             let change = match WorkspaceEditChange::from_json(change, json) {
                 Ok(change) => change,
@@ -621,8 +667,7 @@ impl WorkspaceEdit {
                             let buffer = editor.buffers.add_new();
                             buffer.properties = BufferProperties::scratch();
                             buffer.properties.saving_enabled = true;
-                            buffer.path.clear();
-                            buffer.path.push(path);
+                            buffer.set_path(path);
                             let _ = buffer
                                 .read_from_file(&mut editor.word_database, &mut editor.events);
                             (true, buffer.handle())
@@ -717,8 +762,13 @@ impl<'json> FromJson<'json> for WorkspaceEdit {
             _ => return Err(JsonConvertError),
         };
         let mut this = Self::default();
-        let changes = value.get("documentChanges", json);
-        this.document_changes = FromJson::from_json(changes, json)?;
+        for (key, value) in value.members(json) {
+            match key {
+                "changes" => this.changes = FromJson::from_json(value, json)?,
+                "documentChanges" => this.document_changes = FromJson::from_json(value, json)?,
+                _ => (),
+            }
+        }
         Ok(this)
     }
 }
@@ -1117,3 +1167,27 @@ impl PendingRequestColection {
         None
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn parse_uri() {
+        fn assert_uri(expect: &str, raw: &str) {
+            match Uri::parse(Path::new("/home"), raw) {
+                Ok(Uri::Path(uri)) => assert_eq!(Path::new(expect), uri),
+                Err(_) => panic!("could not parse uri {}", raw),
+            }
+        }
+
+        assert_uri("file.rs", "file:///home/file.rs");
+        assert_uri("dir/file.rs", "file:///home/dir/file.rs");
+        assert_uri("/etc/file.rs", "file:///etc/file.rs");
+
+        if cfg!(windows) {
+            assert_uri("C:/file.rs", "file:///C:/file.rs");
+            assert_uri("c:/file.rs", "file:///c:/file.rs");
+        }
+    }
+}
